import org.geotools.referencing.CRS;
import org.jetel.component.CTLRecordTransform;
import org.jetel.component.DataRecordTransform;
import org.jetel.data.DataRecord;
import org.jetel.exception.ComponentNotReadyException;
import org.opengis.referencing.FactoryException;
import org.opengis.referencing.crs.CoordinateReferenceSystem;
import org.opengis.referencing.operation.MathTransform;
import org.opengis.referencing.operation.TransformException;


public final class DemoCRSTransformation extends DataRecordTransform {

	MathTransform conversion;

	@Override
	public boolean init() throws ComponentNotReadyException {
    	try {
    		
			//prepare CRS in which our input data will arrive
			//WGS 84
		    //http://spatialreference.org/ref/epsg/4326/
			CoordinateReferenceSystem crsFrom = CRS.decode("EPSG:4326");
		
			//prepare desired CSR for output data
			//NAD83 / UTM zone 18N
			//http://spatialreference.org/ref/epsg/26918/
			CoordinateReferenceSystem crsTo = CRS.decode("EPSG:26918");

	        //prepare transformation object
			conversion = CRS.findMathTransform(crsFrom, crsTo, true);
			
    	} catch (FactoryException e) {
    		throw new ComponentNotReadyException("Error getting coordinate systems!", e);
    	}

    	return true;
		
    }

	
    @Override
	public int transform(DataRecord[] in, DataRecord[] out)
			throws org.jetel.exception.TransformException {

    	//input point
		double fromPoint[] = new double[]{
			(java.lang.Double) in[0].getField(0).getValue(),
			(java.lang.Double) in[0].getField(1).getValue()
		};

		//output point
		double toPoint[] = new double[2];

		try {
			//convert 1 point from fromPoint with offset 0
			//into toPoint with offset 0
			conversion.transform(fromPoint, 0, toPoint, 0, 1);
		} catch (TransformException e) {
			throw new org.jetel.exception.TransformException("Error during transformation!", e);
		}

        out[0].getField(0).setValue(toPoint[0]);
        out[0].getField(1).setValue(toPoint[1]);
        
        return OK;
        
	}
    
}
